' This file is part of Network Switcher.

' Network Switcher is free software: you can redistribute it and/or modify
' it under the terms of the GNU General Public License as published by
' the Free Software Foundation, either version 3 of the License, or
' (at your option) any later version.

' Network Switcher is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.

' You should have received a copy of the GNU General Public License
' along with Network Switcher. If not, see <http://www.gnu.org/licenses/>.
'
' Copyright 2007, Ricardo Amaral

Imports Microsoft.Win32

Public Class FormSettings

#Region " Controls Events "

    ' Save settings
    Private Sub btnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSave.Click
        SaveSettings()
    End Sub

    Private Sub txtNicFolder_KeyPress(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles txtNicFolder.KeyPress
        ' Did the user pressed the Return key?
        If e.KeyChar = Convert.ToChar(Keys.Return) Then
            e.Handled = True
            SaveSettings()
        End If
    End Sub

    ' Enable/Disable proxy GroupBox
    Private Sub radDirect_CheckedChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles radDirect.CheckedChanged
        Me.gbxManualProxy.Enabled = False
    End Sub

    Private Sub radManual_CheckedChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles radManual.CheckedChanged
        Me.gbxManualProxy.Enabled = True
    End Sub

#End Region

#Region " Form Events "

    ' Load all settings from the Settings Structure
    Private Sub frmSettings_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        Me.chkStartup.Checked = Settings.WindowsStartup
        Me.chkStartHidden.Checked = Settings.StartHidden
        Me.chkExitOnClosing.Checked = Settings.ExitOnClosing
        Me.txtNicFolder.Text = Settings.NicFolder
        Me.txtEnableVerb.Text = Settings.EnableVerb
        Me.txtDisableVerb.Text = Settings.DisableVerb
        Me.txtAddress.Text = Settings.ProxyAddress
        Me.chckBypassLocal.Checked = Settings.BypassLocal

        If Settings.ProxyPort > 0 Then
            Me.txtPort.Text = Settings.ProxyPort
        End If

        If Settings.DirectConnection Then
            Me.radDirect.Checked = True
            Me.radManual.Checked = False
            Me.gbxManualProxy.Enabled = False
        Else
            Me.radDirect.Checked = False
            Me.radManual.Checked = True
            Me.gbxManualProxy.Enabled = True
        End If
    End Sub

#End Region

#Region " Private Methods "

    ' Method: If everything is correct, save the settings
    Private Sub SaveSettings()
        Dim nicFolder As Shell32.Folder = GetNetworkConnectionsFolder(Me.txtNicFolder.Text)

        ' Do we have a valid network connections folder and valid verbs?
        If nicFolder Is Nothing Then
            MessageBox.Show("The Network Connections folder was not found, settings can't be saved.", "Invalid Settings!", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        ElseIf Me.txtEnableVerb.Text = "" Or Me.txtDisableVerb.Text = "" Then
            MessageBox.Show("The enable verb and the disable verb are both empty, settings can't be saved.", "Invalid Settings!", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        Else
            ' Set the updated startup value in the registry?
            If Not Settings.WindowsStartup = Me.chkStartup.Checked Then
                Dim regKey As RegistryKey

                ' Set registry key for opening
                regKey = Registry.CurrentUser.OpenSubKey("Software\Microsoft\Windows\CurrentVersion\Run", True)

                If Me.chkStartup.Checked Then
                    ' Write key if it's not already there
                    If regKey.GetValue("Network Switcher") Is Nothing Then
                        regKey.SetValue("Network Switcher", Application.ExecutablePath, RegistryValueKind.String)
                    End If
                Else
                    ' Delete key if it exists
                    If Not (regKey.GetValue("Network Switcher") Is Nothing) Then
                        regKey.DeleteValue("Network Switcher", True)
                    End If
                End If

                ' Close opened registry key
                regKey.Close()
            End If

            ' Save settings to friend application variable
            Settings.WindowsStartup = Me.chkStartup.Checked
            Settings.StartHidden = Me.chkStartHidden.Checked
            Settings.ExitOnClosing = Me.chkExitOnClosing.Checked
            Settings.NicFolder = Me.txtNicFolder.Text
            Settings.EnableVerb = Me.txtEnableVerb.Text
            Settings.DisableVerb = Me.txtDisableVerb.Text
            Settings.DirectConnection = Me.radDirect.Checked
            Settings.ProxyAddress = Me.txtAddress.Text
            Settings.BypassLocal = Me.chckBypassLocal.Checked

            ' Is the port number numeric and higher than 0?
            If IsNumeric(Me.txtPort.Text) Then
                If Me.txtPort.Text > 0 Then
                    Settings.ProxyPort = Me.txtPort.Text
                End If
            End If

            ' Sets proxy settings to plugins interface
            SetProxySettingsToInterface()

            ' Reset network connections folder
            ShellItems.NicFolder = nicFolder

            ' Initialize XML settings file
            XML = New XMLParser(Application.StartupPath, "settings", "Settings")

            ' Save all settings to the XML file
            XML.SaveSettingStr("Global", "WindowsStartup", Settings.WindowsStartup.ToString)
            XML.SaveSettingStr("Global", "StartHidden", Settings.StartHidden.ToString)
            XML.SaveSettingStr("Global", "ExitOnClosing", Settings.ExitOnClosing.ToString)
            XML.SaveSettingStr("Global", "NICFolder", Settings.NicFolder.ToString)
            XML.SaveSettingStr("Global", "EnableVerb", Settings.EnableVerb.ToString)
            XML.SaveSettingStr("Global", "DisableVerb", Settings.DisableVerb.ToString)
            XML.SaveSettingStr("Proxy", "DirectConnection", Settings.DirectConnection.ToString)
            XML.SaveSettingStr("Proxy", "Address", Settings.ProxyAddress.ToString)
            XML.SaveSettingInt("Proxy", "Port", Settings.ProxyPort)
            XML.SaveSettingStr("Proxy", "BypassLocal", Settings.BypassLocal.ToString)

            ' Set 'OK' dialog result and close the form
            Me.DialogResult = Windows.Forms.DialogResult.OK
            Me.Close()
        End If
    End Sub

#End Region

End Class